/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998-1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeffrey Hammel <jhammel@mozilla.com>
 *   Jonathan Griffin <jgriffin@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gAppName;
var gProfileService;
var gAppDefault;
var gApps;
var gAddedApp = "none";
var gApp;
var gBundle;
var ProfileManager;

/**
 * Handle the select even for the dropdown list.  If 'Other' is selected,
 * use a file picker dialog to add a new item to the list.
 */
function onSelect_AppMenu(menu) {
  if (menu.selectedIndex == -1) return;
  let item = menu.getItemAtIndex(menu.selectedIndex);
  if (item.getAttribute("value") == "Other") {
    // Use the file picker dialog to add another item to the list
    var thefile = chooseBinaryWithFilePicker(gApp);
    if (thefile) {
      gProfileApp = thefile.path;
      let appPresent = false;
      for each (let appVersion in gApps) {
        if (appVersion.path.toLowerCase() == thefile.path.toLowerCase()) {
          appPresent = true;
        }
      }
      if (!appPresent) {
        gApps.push({path: thefile.path, version: getAppVersion(thefile.path)});
        gAddedApp = thefile.path;
      }
    }
    update_menu();
  }
}

/**
 * Populate the dropdown menu.
 */
function update_menu() {
  // TODO: if menu items are too long, truncate them in some reasonable way
  let menu = document.getElementById("versionmenu");
  menu.removeAllItems();
  if (gAppDefault) {
    menu.appendItem(
        gBundle.getFormattedString(
          'appDesc',
          [gAppDefault.path, getAppVersion(gAppDefault.path)]), 
        gAppDefault.path);
  }
  for (let i in gApps) {
    if (gApps[i].path.toLowerCase() != gAppDefault.path.toLowerCase()) {
      menu.appendItem(gBundle.
          getFormattedString(
            'appDesc',
            [gApps[i].path, gApps[i].version]),
          gApps[i].path);
      if (gApps[i].path.toLowerCase() == gAddedApp.toLowerCase()) {
        menu.selectedIndex = menu.itemCount - 1;
      }
    }
  }
  menu.appendItem(gBundle.getString('createProfAppNone'), null);
  menu.appendItem(gBundle.getString('createProfAppOther'), "Other");
  if (menu.selectedIndex == -1) {
    menu.selectedIndex = 0;
  }
}

/**
 * Create the new profile.
 */
function onClick_OK(){
  // get the parameters from the document
  var name = document.getElementById('name').value;
  var isDefault = document.getElementById('default').checked;
  let menu = document.getElementById("versionmenu");
  let item = menu.getItemAtIndex(menu.selectedIndex);
  let appPath = item.getAttribute('value');
  let location = document.getElementById("location").value;
  let profilePath = undefined;
  if (location.toLowerCase() != 
      ProfileManager.profileDirectory.path.toLowerCase())
    profilePath = location;

  // create the profile
  try {
    gProfileService.newProfile(name, isDefault, profilePath);
  } catch(e) {
    alert(e);
    return false;
  }

  window.arguments[0].out = {name: name,
                             appPath: appPath};
  return true;
}

/**
 * Handle the 'cancel' button.
 */
function onClick_Cancel(){
  return true;
}

/**
 * Handle the window's 'load' event.
 */
function onLoad() {
  // set globals
  gAppName = window.arguments[0].in.appName;
  gProfileService = window.arguments[0].in.gProfileService;
  gAppDefault = window.arguments[0].in.appDefault;
  ProfileManager = window.arguments[0].in.ProfileManager;
  gApps = window.arguments[0].in.apps;
  gApp = window.arguments[0].in.app;
  gBundle = document.getElementById("bundle_profileManager");

  // update UI elements
  let desc = gBundle.getFormattedString("createProfDesc", [gAppName]);
  document.getElementById("createProfileDesc").
           appendChild(document.createTextNode(desc));
  update_menu();
  document.getElementById("location").value = 
    ProfileManager.profileDirectory.path;

  // set dialog's size and position
  centerDialogToParent();
}

/**
 * Handle the 'Use default' button by overwriting anything in the 'location'
 * box with the default profile directory.
 */
function onClick_UseDefault() {
  document.getElementById("location").value = 
    ProfileManager.profileDirectory.path;
}

